﻿using System;
using System.Collections.Generic;
using System.Linq;
using System.Web;
using System.Web.Mvc;
using ThinkGeo.MapSuite.Core;
using ThinkGeo.MapSuite.MvcEdition;

namespace GenerateCacheTest.Controllers
{
    public class HomeController : Controller
    {
        private Map map;

        //
        // GET: /Home/

        public ActionResult Index()
        {
            var initialExtent = new RectangleShape(new PointShape(-5297800.03865739, -2500515.68661611), new PointShape(-5296705.19107185, -2501616.88524453));

            InitializeMap();

            var google = new GoogleOverlay(GoogleMapType.Normal);
            google.JavaScriptLibraryUri = new Uri(@"http://maps.google.com/maps/api/js?sensor=false");

            map.CustomOverlays.Add(google);
            var overlay = new LayerOverlay("Custom");

            var layer = new CustomLayer();
            layer.Name = "Custom";
            layer.Open();
            overlay.Layers.Add(layer);

            overlay.ServerCache = new ServerCache(@"c:\temp\CacheFolder\");
            overlay.ServerCache.CacheId = "Testing";
            overlay.ClientCache = new ClientCache(TimeSpan.FromMinutes(15), "Testing");

            map.CustomOverlays.Add(overlay);

            overlay.GenerateCacheImages(new GoogleMapsZoomLevelSet().ZoomLevel17.Scale, initialExtent, map.MapUnit);

            map.CurrentExtent = initialExtent;

            return View(map);
        }

        private void InitializeMap()
        {
            map = new Map("Mapa",
                new System.Web.UI.WebControls.Unit(100, System.Web.UI.WebControls.UnitType.Percentage),
                new System.Web.UI.WebControls.Unit(100, System.Web.UI.WebControls.UnitType.Percentage));

            map.MapUnit = GeographyUnit.Meter;

            map.MapTools.MouseCoordinate.Enabled = false;
            map.MapTools.LoadingImage.Enabled = true;
            map.MapTools.MiniMap.Enabled = true;

            map.MapBackground = new BackgroundLayer(new GeoSolidBrush(GeoColor.FromHtml("#E5E3DF")));
        }

    }
}
