﻿using System;
using System.Collections.Generic;
using System.Linq;
using System.Web;
using ThinkGeo.MapSuite.Core;

namespace GenerateCacheTest
{
    public class CustomLayer : Layer
    {
        private readonly ManagedProj4Projection Proj;
        private readonly string filePath;

        public CustomLayer()
        {
            Proj = new ManagedProj4Projection();
            Proj.InternalProjectionParametersString = ManagedProj4Projection.GetEpsgParametersString(32723);
            Proj.ExternalProjectionParametersString = ManagedProj4Projection.GetGoogleMapParametersString();
            Proj.Open();

            filePath = HttpContext.Current.Server.MapPath("~/07_X_04.tif");

            var temp = new GeoTiffRasterLayer(filePath);
            temp.Open();
            boundingBox = Proj.ConvertToExternalProjection(temp.GetBoundingBox());
            temp.Close();
        }

        public override bool HasBoundingBox
        {
            get
            {
                return true;
            }
        }

        private RectangleShape boundingBox;
        protected override RectangleShape GetBoundingBoxCore()
        {
            return boundingBox;
        }

        protected override void OpenCore()
        {


            base.OpenCore();
        }

        protected override void DrawCore(GeoCanvas canvas, System.Collections.ObjectModel.Collection<SimpleCandidate> labelsInAllLayers)
        {
            var currentExtent = canvas.CurrentWorldExtent;

            if (currentExtent.Intersects(boundingBox))
            {
                var rasterLayer = new GeoTiffRasterLayer(filePath);
                rasterLayer.ImageSource.Projection = Proj;
                rasterLayer.Open();
                rasterLayer.Draw(canvas, labelsInAllLayers);
                rasterLayer.Close();
            }
            //currentExtentEnvelope.ExpandBy(1000);
        }

        protected override void CloseCore()
        {
            base.CloseCore();
        }

    }
}